;; Generated package description from logos.el  -*- no-byte-compile: t -*-
(define-package "logos" "0.5.1" "Simple focus mode and extras" '((emacs "27.1")) :commit "be3333b6969c34bb3317d11f1daef6aa5af476cb" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Logos Development" . "~protesilaos/logos@lists.sr.ht") :keywords '("convenience" "focus" "writing" "presentation" "narrowing") :url "https://git.sr.ht/~protesilaos/logos")
